<?php
/* List View class
 *
 * Created By David Cornewell
*/

require_once("db_mysql.inc.php");

class phpListViewColumn {
	var $columnname;
	var $title;
	var $escape;
	var $show;
	var $formatter;
	var $callback;
	var $userdata;
	var $allow_ordering;
		
	function phpListViewColumn($columnname, $title, $escape, $show, $formatter, $callback, $userdata, $allow_ordering)
	{
		$this->columnname = $columnname;
		$this->title      = $title;    
		$this->escape     = $escape;   
		$this->show			= $show;
		$this->formatter  = $formatter;
		$this->callback   = $callback; 
		$this->userdata   = $userdata; 
		$this->allow_ordering = $allow_ordering;

		return $this;
	}	
}

class phpListViewCellData {
	var $row;
	var $coluserdata;
	var $cellnum;
	var $lv;
	
	function phpListViewCellData($row,$coluserdata,$cellnum,$lv)
	{
		$this->row = $row;
		$this->coluserdata = $coluserdata;
		$this->cellnum = $cellnum;
		$this->lv = $lv;
	}
}

class phpListViewCtrl {
	var $conn;
	var $cgi;
	var $name;
	var $title;
	var $userdata;
	var $columns;
	var $orderby;
	var $orderdir;
	var $deflimit;
	var $addselect;
	var $limit;
	var $offset;

	function phpListViewCtrl($conn, $cgi, $name, $title, $userdata)
	{
		$this->name     = $name;    		
		$this->title    = $title;   		
		$this->userdata = $userdata;		
		$this->conn=$conn;
		$this->cgi=$cgi;
		$this->columns = array();
		$this->orderby = "";
		$this->orderdir = "";
		$this->addselect = "";
		$this->limit=20;
		$this->offset=0;
	}
	
	function AddColumn($columnname, $title, $escape, $formatter, $callback, $userdata)
	{
		$this->AddColumnShow($columnname, $title, $escape, true, $formatter, $callback, $userdata);
	}

	function AddColumnShow($columnname, $title, $escape, $show, $formatter, $callback, $userdata)
	{
		$this->AddColumnShowOrder($columnname, $title, $escape, $show, $formatter, $callback, $userdata, true);
	}

	function AddColumnShowOrder($columnname, $title, $escape, $show, $formatter, $callback, $userdata, $allow_ordering)
	{
		$this->columns[] = new phpListViewColumn($columnname, $title, $escape, $show, $formatter, $callback, $userdata, $allow_ordering);
	}

	function AddSelect($addselect)
	{
		$this->addselect=$addselect;
	}

	function SetLimit($limit)
	{
		$this->limit=$limit;
	}

	function SetDefOrderBy($orderby,$orderdir)
	{
		$this->orderby = $orderby;
		$this->orderdir = $orderdir;
	}
			
	function Render()
	{
		//
		// Use order that was clicked on.
		//
		if ($this->cgi->var_val($this->name."orderby")) {
			$this->orderby=$this->cgi->var_val($this->name."orderby");
			$this->orderdir=$this->cgi->var_val($this->name."orderdir");
		}
		
		//
		// Use offset from cgi
		//
		if ($this->cgi->var_val($this->name."offset")) {
			$this->offset=$this->cgi->var_val($this->name."offset");
		}
		if ($this->cgi->var_val($this->name."limit")) {
			$this->limit=$this->cgi->var_val($this->name."limit");
		}
		
		$select = "SELECT ".$this->columns[0]->columnname;
		for ($i=1; $i<count($this->columns); $i++) {
			$select .= ", " . $this->columns[$i]->columnname;
		}
		$select .= " " . $this->addselect;
		if (strlen($this->orderby)>0) {
			$select .= " ORDER BY " . $this->orderby ." ". $this->orderdir;
		}
		if ($this->limit>0) {
			$select .= " LIMIT ". $this->offset .",". $this->limit;
		}
		
		$res = DBQuery($select,$this->conn);
		if ($res) {
			print "<table border=1 align=center width=\"98%\" cellpadding=1 cellspacing=0>\n";
			print "<tr><td align=\"center\" colspan=\"". count($this->columns) ."\" class=\"title\">". $this->title ."</td></tr>\n";
			print "<tr align=center>\n";
			for ($i=0; $i<count($this->columns); $i++) {
				print "<td class=\"subtitle\">";
				if ($this->columns[$i]->allow_ordering) {
					if (strpos($this->columns[$i]->columnname, "AS")>0) {
						$name = substr($this->columns[$i]->columnname, strpos($this->columns[$i]->columnname,"AS")+3);
					} else {
						$name=$this->columns[$i]->columnname;
					}
					print "<a class=\"subtitle\" href=\"". $this->cgi->generate_uri() ."&amp;";
					if ($this->orderby==$name && $this->orderdir=="ASC")print $this->name ."orderdir=DESC"; 
					else print $this->name ."orderdir=ASC";
					print "&amp;". $this->name ."orderby=". $name ."\">". $this->columns[$i]->title ."</a>";
				} else {
					print $this->columns[$i]->title;
				}
				print "</td>\n";
			}
			print "</tr>\n";
	
			$rowcounter=0;
			while ( ($row=DBGetRow($res)) ) {
				print "<tr align=center>\n";
				for ($i=0; $i<count($this->columns); $i++) {
					if ($rowcounter%3) print "<td class=\"lvrow\">\n";
					else print "<td class=\"lvaltrow\">\n";
					if ($this->columns[$i]->callback) {
						$celldata = new phpListViewCellData($row, $this->columns[$i]->userdata, $i, $this);
						call_user_func($this->columns[$i]->callback,$celldata);
					} else if (strlen($row[$i])) {
						print $row[$i];
					} else {
						print "&nbsp;";
					}
					print "</td>\n";
				}
				print "</tr>\n";
				$rowcounter++;
			}
			print "<tr align=center>\n";
			print "<td colspan=". count($this->columns) ." class=\"subtitle\">\n";
			if ($this->offset > 0) {
				$prev=$this->offset-$this->limit;
				print "<a href=\"". $this->cgi->generate_uri() ."&amp;". $this->name ."offset=". $prev;
				print "\">Prev</a> ";
			}
			print "Displaying ";
			print $offset+1;
			print " to ";
			print DBnumrows($res)+$this->offset;
			if ($this->limit>0 && DBnumrows($res) >= $this->limit) {
				$next = $this->offset+$this->limit;
				print " <a class=\"subtitle\" href=\"". $this->cgi->generate_uri() ."&amp;". $this->name ."offset=". $next;
				print "\">Next</a>";
			}
			print "</td>\n";
			print "</tr>\n";
			print "</table>\n";
			
			DBFreeResult($res);
		} else {
			print "Error creating list view<br>".DBErrorMsg($this->conn) ."<br>". $select;
		}
	}
	
}

?>
